# Hume AI Python SDK

The Hume AI Python SDK makes it easy to call Hume APIs from Python applications.

To get started, [sign up for a Hume account](https://beta.hume.ai/sign-up)!

## Usage & Documentation

For usage examples check out the [full documentation](https://humeai.github.io/hume-python-sdk/).

## Other Resources

- [Hume AI Homepage](https://hume.ai)
- [Platform Documentation](https://help.hume.ai/basics/about-hume-ai)
- [API Reference](https://docs.hume.ai)

## Support

If you've found a bug with this SDK please [open an issue](https://github.com/HumeAI/hume-python-sdk/issues/new)!
